.. _installation:

============
Installation
============

Install shellplot via ``pip``::

    pip install --upgrade shellplot


This will install the latest stable version, as well as the required
dependencies.
